@@ -8,6 +8,8 @@ import os
 
 @ui.page('/')
 def page_home(
+    d: bool | None = None, # dark mode
+    f: bool | None = None, # fullscreen # TODO
     t: str | None = None, # Token for using custom data: allow users to pass a custom token, which won't be stored, via a parameter when using public devices. For personal devices, enable persistent settings using `custom_token`.
     k: bool | None = True, # keep valid specified parameters in history
     m: bool | None = True, # display menu
@@ -26,28 +28,35 @@ def page_home(
     Home page that accepts optional parameters.
     Example: /?bb=1&bc=1&bv=1
     """
-
     def set_default_settings():
         """Sets the default settings in app.storage.user if they don't already exist."""
         for key, value in USER_DEFAULT_SETTINGS.items():
             if key not in app.storage.user:
                 app.storage.user[key] = value
-
     # Call this once on startup to populate the default user storage
     set_default_settings()
 
+    # spacing
+    ui.query('.nicegui-content').classes('w-full h-full !p-0 !b-0 !m-0 !gap-0')
+
+    # primary color
+    ui.colors(primary=app.storage.user["primary_colour"], secondary=app.storage.user["secondary_colour"])
+
     # Bind app state to user storage
     ui.dark_mode().bind_value(app.storage.user, 'dark_mode')
+    app.storage.user["fullscreen"] = False
     ui.fullscreen().bind_value(app.storage.user, 'fullscreen')
 
+    if d is not None:
+        app.storage.user['dark_mode'] = d
+    if f is not None:
+        app.storage.user['fullscreen'] = f
+
     # manage custom resources
     if not config.custom_token or (t and t == config.custom_token) or (app.storage.user.setdefault('custom_token', "") == config.custom_token):
         app.storage.client["custom"] = True # short-term memory (single page visit)
-
-    # Use app.storage.user to store session-specific state
-    # This keeps the settings unique for each user
-    app.storage.user.setdefault('left_drawer_open', False)
-    app.storage.user.setdefault('sync', True) # TODO - add disable sync option later
+    else:
+        app.storage.client["custom"] = False
 
     if l is not None and l in (1, 2, 3):
         app.storage.user['layout'] = l
@@ -114,49 +123,47 @@ def page_home(
         ... # TODO - decides later
 
 # Settings
-
-"""
-@ui.page('/settings')
-def page_Settings(q: str | None = None, m: bool = True):
-    if m:
-        BibleMateGUI().create_menu()
-    ...
-"""
-
 @ui.page('/settings')
 def page_Settings():
     """The main settings page for the BibleMate AI app."""
-
     def set_default_settings():
         """Sets the default settings in app.storage.user if they don't already exist."""
         for key, value in USER_DEFAULT_SETTINGS.items():
             if key not in app.storage.user:
                 app.storage.user[key] = value
-
     # We can call this again to be safe, especially if new settings are added in updates.
     set_default_settings()
 
+    # primary color
+    ui.colors(primary=app.storage.user["primary_colour"], secondary=app.storage.user["secondary_colour"])
+
     # Bind app state to user storage
     ui.dark_mode().bind_value(app.storage.user, 'dark_mode')
+    app.storage.user["fullscreen"] = False
     ui.fullscreen().bind_value(app.storage.user, 'fullscreen')
 
     with ui.card().classes('w-full max-w-2xl mx-auto p-6 shadow-xl rounded-lg'):
-        ui.label('BibleMate AI Settings').classes('text-3xl font-bold text-gray-800 mb-6')
+        ui.label('BibleMate AI Settings').classes('text-3xl font-bold text-secondary mb-6')
         
         # --- Appearance Section ---
         with ui.expansion('Appearance', icon='palette').classes('w-full rounded-lg'):
             with ui.column().classes('w-full p-4'):
                 ui.color_input(label='Primary Color') \
-                    .bind_value(app.storage.user, 'primary_color') \
-                    .tooltip('Manual hex code or color picker for app theme.')
-                
-                ui.switch('Dark Mode') \
-                    .bind_value(app.storage.user, 'dark_mode') \
-                    .tooltip('Toggle dark mode for the app.')
-
-                ui.switch('Fullscreen') \
-                    .bind_value(app.storage.user, 'fullscreen') \
-                    .tooltip('Toggle fullscreen mode for the app.')
+                    .bind_value(app.storage.user, 'primary_colour') \
+                    .tooltip('Manual hex code or color picker for app theme.') \
+                    .on_value_change(lambda: ui.run_javascript('location.reload()'))
+                ui.color_input(label='Secondary Color') \
+                    .bind_value(app.storage.user, 'secondary_colour') \
+                    .tooltip('Manual hex code or color picker for app theme.') \
+                    .on_value_change(lambda: ui.run_javascript('location.reload()'))
+                with ui.row().classes('w-full'):
+                    ui.label("Dark Mode").classes('flex items-center')
+                    ui.space()
+                    ui.switch().bind_value(app.storage.user, 'dark_mode').tooltip('Toggle dark mode for the app.').on_value_change(lambda: ui.run_javascript('location.reload()'))
+                with ui.row().classes('w-full'):
+                    ui.label("Fullscreen").classes('flex items-center')
+                    ui.space()
+                    ui.switch().bind_value(app.storage.user, 'fullscreen').tooltip('Toggle fullscreen mode for the app.')
 
         # --- User & Custom Data Section ---
         with ui.expansion('User & Custom Data', icon='person').classes('w-full rounded-lg'):
@@ -180,7 +187,7 @@ def page_Settings():
                     .bind_value(app.storage.user, 'default_bible')
 
                 ui.select(label='Default Commentary',
-                          options=['Cambridge', 'CBC', 'Calvin']) \
+                          options=['CBSC', 'CBC', 'Calvin']) \
                     .bind_value(app.storage.user, 'default_commentary')
 
                 ui.select(label='Default Encyclopedia',
@@ -188,7 +195,7 @@ def page_Settings():
                     .bind_value(app.storage.user, 'default_encyclopedia')
 
                 ui.select(label='Default Lexicon',
-                          options=['Strong', 'HALOT', 'BDAG']) \
+                          options=['Morphology', 'Strong', 'HALOT', 'BDAG']) \
                     .bind_value(app.storage.user, 'default_lexicon')
 
         # --- AI Backend Section ---
@@ -217,9 +224,9 @@ def page_Settings():
                     .bind_value(app.storage.user, 'language')
 
         # --- Save Feedback ---
-        ui.button('Save Confirmation', on_click=lambda: ui.notify('Settings saved!', color='positive')) \
+        ui.button('Home', on_click=lambda: ui.navigate.to('/')) \
             .classes('mt-6 w-full py-3 bg-blue-600 text-white rounded-lg font-semibold') \
-            .tooltip('All settings are saved automatically as you change them. Click this to confirm.')
+            .tooltip('All settings are saved automatically as you change them. Click this to open the home page.')
 
 # Entry_point
 
@@ -231,7 +238,7 @@ def main():
         storage_secret=config.storage_secret, # e.g. generate one by running `openssl rand -hex 32` or `openssl rand -base64 32`
         port=config.port,
         title='BibleMate AI',
-        favicon=config.avatar if config.avatar else os.path.join(BIBLEMATEGUI_APP_DIR, 'eliranwong.jpg')
+        favicon=os.path.expanduser(config.avatar) if config.avatar else os.path.join(BIBLEMATEGUI_APP_DIR, 'eliranwong.jpg')
     )
 
 main()
\ No newline at end of file
