@@ -1,6 +1,6 @@
-from nicegui import ui
+from nicegui import ui, app
 from biblemategui import BIBLEMATEGUI_DATA
-from biblemategui.css.original import ORIGINAL_CSS
+from biblemategui.css.original import get_original_css
 from biblemategui.fx.bible import *
 from biblemategui.fx.original import *
 from biblemategui.js.sync_scrolling import *
@@ -25,6 +25,7 @@ def original_interlinear(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None,
 
     # Fix known issues
     content = content.replace("<br<", "<br><")
+    content = content.replace("<heb> </heb>", "<heb>&nbsp;</heb>")
 
     # convert verse link, like '<vid id="v19.117.1" onclick="luV(1)">'
     content = re.sub(r'<vid id="v([0-9]+?)\.([0-9]+?)\.([0-9]+?)" onclick="luV\(([0-9]+?)\)">', r'<vid id="v\1.\2.\3" onclick="luV(\1, \2, \3)">', content)
@@ -35,86 +36,82 @@ def original_interlinear(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None,
 
     # Inject CSS to handle the custom tags and layout
     if "</heb>" in content:
-        ui.add_head_html("""
+        ui.add_head_html(f"""
         <style>
             /* Main container for the Bible text - ensures RTL flow for verses */
-            .bible-text {
+            .bible-text {{
                 direction: rtl;
                 font-family: sans-serif;
-                padding: 20px;
-                background-color: #fafafa;
-            }
+                padding: 0px;
+                margin: 0px;
+            }}
             /* Verse ID Number */
-            vid {
-                color: navy;
+            vid {{
+                color: {'#f2c522' if app.storage.user['dark_mode'] else 'navy'};
                 font-weight: bold;
                 font-size: 0.9rem;
                 margin-left: 10px; /* appears on the right due to RTL */
                 cursor: pointer;
-            }
+            }}
             /* Hebrew Word Layer */
-            wform, heb, bdbheb, bdbarc, hu {
+            wform, heb, bdbheb, bdbarc, hu {{
                 font-family: 'SBL Hebrew', 'Ezra SIL', serif;
                 font-size: 1.6rem;
-                color: #2c3e50;
                 direction: rtl;
                 display: inline-block;
                 line-height: 1.2em;
                 margin-top: 0;
                 margin-bottom: -2px;
                 cursor: pointer;
-            }
+            }}
             /* Lexical Form & Strong's Number Layers */
-            wlex {
-                display: block;
+            wlex {{
+                display: inline-block;
                 font-family: 'SBL Hebrew', serif;
                 font-size: 1rem;
-                color: #555;
                 cursor: pointer;
-            }
+            }}
         </style>
         """)
     else:
-        ui.add_head_html("""
+        ui.add_head_html(f"""
         <style>
             /* Main container for the Bible text - LTR flow for Greek */
-            .bible-text {
+            .bible-text {{
                 direction: ltr;
                 font-family: sans-serif;
-                padding: 20px;
-                background-color: #fafafa;
-            }
+                padding: 0px;
+                margin: 0px;
+            }}
             /* Verse ID Number */
-            vid {
-                color: navy;
+            vid {{
+                color: {'#f2c522' if app.storage.user['dark_mode'] else 'navy'};
                 font-weight: bold;
                 font-size: 0.9rem;
                 margin-right: 10px;
                 cursor: pointer;
-            }
+            }}
             /* Greek Word Layer (targets <grk> tag) */
-            wform, grk, kgrk, gu {
+            wform, grk, kgrk, gu {{
                 font-family: 'SBL Greek', 'Galatia SIL', 'Times New Roman', serif; /* CHANGED */
                 font-size: 1.6rem;
-                color: #2c3e50;
                 direction: ltr;
                 display: inline-block;
                 line-height: 1.2em;
                 margin-top: 0;
                 margin-bottom: -2px;
                 cursor: pointer;
-            }
+            }}
             /* Lexical Form (lemma) & Strong's Number Layers */
-            wlex {
-                display: block;
+            wlex {{
+                display: inline-block;
                 font-family: 'SBL Greek', 'Galatia SIL', 'Times New Roman', serif; /* CHANGED */
                 font-size: 1rem;
-                color: #555;
                 cursor: pointer;
-            }
+            }}
         </style>
         """)
-    ui.add_head_html(ORIGINAL_CSS)
+    ui.add_head_html(get_original_css(app.storage.user['dark_mode']))
 
     # Bible Selection menu
     bible_selector = BibleSelector(on_version_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_book_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_chapter_changed=gui.change_area_1_bible_chapter if area == 1 else gui.change_area_2_bible_chapter, on_verse_changed=change_bible_chapter_verse)
