@@ -4,14 +4,21 @@ from functools import partial
 
 from biblemategui import config, BIBLEMATEGUI_APP_DIR
 
-from biblemategui.pages.tools.audio import bibles_audio
-from biblemategui.pages.tools.chronology import bible_chronology
-
 from biblemategui.pages.ai.chat import ai_chat
 
 from biblemategui.js.bible import BIBLE_JS
-from biblemategui.js.original import ORIGINAL_JS
+from biblemategui.js.original import get_original_js
 
+# Import for page content
+from biblemategui.pages.bibles.original_reader import original_reader
+from biblemategui.pages.bibles.original_interlinear import original_interlinear
+from biblemategui.pages.bibles.original_parallel import original_parallel
+from biblemategui.pages.bibles.original_discourse import original_discourse
+from biblemategui.pages.bibles.original_linguistic import original_linguistic
+from biblemategui.pages.bibles.bible_translation import bible_translation
+
+from biblemategui.pages.tools.audio import bibles_audio
+from biblemategui.pages.tools.chronology import bible_chronology
 
 class BibleMateGUI:
     def __init__(self):
@@ -86,30 +93,30 @@ class BibleMateGUI:
         
         # Inject JS
         ui.add_head_html(BIBLE_JS) # for active verse scrolling
-        ui.add_head_html(ORIGINAL_JS) # for interactive highlighting
+        ui.add_head_html(get_original_js(app.storage.user['dark_mode'])) # for interactive highlighting
 
         # Create self.splitter
-        self.splitter = ui.splitter(value=100, horizontal=self.is_portrait).classes('w-full').style('height: calc(100vh - 64px)')
+        self.splitter = ui.splitter(value=100, horizontal=self.is_portrait).classes('w-full').style('height: 100vh')
         
         # Area 1
         with self.splitter.before:
             previous_tabs1 = sorted([i for i in app.storage.user.keys() if i.startswith("tab1_")])
             default_number_of_tabs1 = 3
 
-            self.area1_wrapper = ui.column().classes('w-full h-full')
+            self.area1_wrapper = ui.column().classes('w-full h-full !gap-0')
             with self.area1_wrapper:
                 self.area1_tabs = ui.tabs().classes('w-full')
                 with self.area1_tabs:
                     if previous_tabs1:
                         for i in range(1, len(previous_tabs1)+1):
                             tab_id = f'tab1_{i}'
-                            ui.tab(f'tab1_{i}', label=app.storage.user.get(previous_tabs1[i-1]).get("label", f'Bible {i}'))
+                            ui.tab(f'tab1_{i}', label=app.storage.user.get(previous_tabs1[i-1]).get("label", f'Bible {i}')).classes('text-secondary')
                             self.area1_tab_counter += 1
                         self.area1_tab_loaded = self.area1_tab_counter
                     if len(previous_tabs1) < default_number_of_tabs1:
                         for i in range(len(previous_tabs1)+1, default_number_of_tabs1+1):
                             tab_id = f'tab1_{i}'
-                            ui.tab(tab_id, label=f'Bible {i}')
+                            ui.tab(tab_id, label=f'Bible {i}').classes('text-secondary')
                             self.area1_tab_counter += 1
                 
                 self.area1_tab_panels_container = ui.tab_panels(self.area1_tabs, value='tab1_1').classes('w-full h-full')
@@ -120,7 +127,7 @@ class BibleMateGUI:
                         for i in range(1, len(previous_tabs1)+1):
                             tab_id = f'tab1_{i}'
                             saved_tab_id = previous_tabs1[i-1]
-                            with ui.tab_panel(tab_id):
+                            with ui.tab_panel(tab_id).classes('w-full h-full !p-0 !b-0 !m-0 !gap-0'):
                                 self.area1_tab_panels[tab_id] = ui.scroll_area().classes(f'w-full h-full {tab_id}')
                                 with self.area1_tab_panels[tab_id]:
                                     args = app.storage.user.get(saved_tab_id)
@@ -135,7 +142,7 @@ class BibleMateGUI:
                     if len(previous_tabs1) < default_number_of_tabs1:
                         for i in range(len(previous_tabs1)+1, default_number_of_tabs1+1):
                             tab_id = f'tab1_{i}'
-                            with ui.tab_panel(tab_id):
+                            with ui.tab_panel(tab_id).classes('w-full h-full !p-0 !b-0 !m-0 !gap-0'):
                                 self.area1_tab_panels[tab_id] = ui.scroll_area().classes(f'w-full h-full {tab_id}')
                                 with self.area1_tab_panels[tab_id]:
                                     ui.label(f'Bible Area - Tab {i}').classes('text-2xl font-bold mb-4')
@@ -146,20 +153,20 @@ class BibleMateGUI:
             previous_tabs2 = sorted([i for i in app.storage.user.keys() if i.startswith("tab2_")])
             default_number_of_tabs2 = 5
 
-            self.area2_wrapper = ui.column().classes('w-full h-full')
+            self.area2_wrapper = ui.column().classes('w-full h-full !gap-0')
             with self.area2_wrapper:
                 self.area2_tabs = ui.tabs().classes('w-full')
                 with self.area2_tabs:
                     if previous_tabs2:
                         for i in range(1, len(previous_tabs2)+1):
                             tab_id = f'tab2_{i}'
-                            ui.tab(f'tab2_{i}', label=app.storage.user.get(previous_tabs2[i-1]).get("label", f'Tool {i}'))
+                            ui.tab(f'tab2_{i}', label=app.storage.user.get(previous_tabs2[i-1]).get("label", f'Tool {i}')).classes('text-secondary')
                             self.area2_tab_counter += 1
                         self.area2_tab_loaded = self.area2_tab_counter
                     if len(previous_tabs2) < default_number_of_tabs2:
                         for i in range(len(previous_tabs2)+1, default_number_of_tabs2+1):
                             tab_id = f'tab2_{i}'
-                            ui.tab(tab_id, label=f'Tool {i}')
+                            ui.tab(tab_id, label=f'Tool {i}').classes('text-secondary')
                             self.area2_tab_counter += 1
                 
                 self.area2_tab_panels_container = ui.tab_panels(self.area2_tabs, value='tab2_1').classes('w-full h-full')
@@ -170,7 +177,7 @@ class BibleMateGUI:
                         for i in range(1, len(previous_tabs2)+1):
                             tab_id = f'tab2_{i}'
                             saved_tab_id = previous_tabs2[i-1]
-                            with ui.tab_panel(tab_id):
+                            with ui.tab_panel(tab_id).classes('w-full h-full !p-0 !b-0 !m-0 !gap-0'):
                                 self.area2_tab_panels[tab_id] = ui.scroll_area().classes(f'w-full h-full {tab_id}')
                                 with self.area2_tab_panels[tab_id]:
                                     args = app.storage.user.get(previous_tabs2[i-1])
@@ -185,7 +192,7 @@ class BibleMateGUI:
                     if len(previous_tabs2) < default_number_of_tabs2:
                         for i in range(len(previous_tabs2)+1, default_number_of_tabs2+1):
                             tab_id = f'tab2_{i}'
-                            with ui.tab_panel(tab_id):
+                            with ui.tab_panel(tab_id).classes('w-full h-full !p-0 !b-0 !m-0 !gap-0'):
                                 self.area2_tab_panels[tab_id] = ui.scroll_area().classes(f'w-full h-full {tab_id}')
                                 with self.area2_tab_panels[tab_id]:
                                     ui.label(f'Tool Area - Tab {i}').classes('text-2xl font-bold mb-4')
@@ -228,20 +235,24 @@ class BibleMateGUI:
         return self.area2_tab_panels_container.value
 
     def get_content(self, title):
-        if title == "ORB":
-            return config.original_reader
+        if title.lower() == "audio":
+            return bibles_audio
+        elif title.lower() == "chronology":
+            return bible_chronology
+        elif title == "ORB":
+            return original_reader
         elif title == "OIB":
-            return config.original_interlinear
+            return original_interlinear
         elif title == "OPB":
-            return config.original_parallel
+            return original_parallel
         elif title == "ODB":
-            return config.original_discourse
+            return original_discourse
         elif title == "OLB":
-            return config.original_linguistic
+            return original_linguistic
         elif app.storage.client["custom"] and title in config.bibles_custom:
-            return config.bible_translation
+            return bible_translation
         elif title in config.bibles:
-            return config.bible_translation
+            return bible_translation
         elif title in config.available_tools:
             return None # TODO
         else:
@@ -355,10 +366,10 @@ class BibleMateGUI:
         new_tab_name = f'tab1_{self.area1_tab_counter}'
         # Add new tab
         with self.area1_tabs:
-            ui.tab(new_tab_name, label=f'Bible {self.area1_tab_counter}')
+            ui.tab(new_tab_name, label=f'Bible {self.area1_tab_counter}').classes('text-secondary')
         # Add new tab panel
         with self.area1_tab_panels_container:
-            with ui.tab_panel(new_tab_name):
+            with ui.tab_panel(new_tab_name).classes('w-full h-full !p-0 !b-0 !m-0 !gap-0'):
                 self.area1_tab_panels[new_tab_name] = ui.scroll_area().classes(f'w-full h-full {new_tab_name}')
                 with self.area1_tab_panels[new_tab_name]:
                     ui.label(f'Bible Area - Tab {self.area1_tab_counter}').classes('text-2xl font-bold mb-4')
@@ -399,10 +410,10 @@ class BibleMateGUI:
         new_tab_name = f'tab2_{self.area2_tab_counter}'
         # Add new tab
         with self.area2_tabs:
-            ui.tab(new_tab_name, label=f'Tool {self.area2_tab_counter}')
+            ui.tab(new_tab_name, label=f'Tool {self.area2_tab_counter}').classes('text-secondary')
         # Add new tab panel
         with self.area2_tab_panels_container:
-            with ui.tab_panel(new_tab_name):
+            with ui.tab_panel(new_tab_name).classes('w-full h-full !p-0 !b-0 !m-0 !gap-0'):
                 self.area2_tab_panels[new_tab_name] = ui.scroll_area().classes(f'w-full h-full {new_tab_name}')
                 with self.area2_tab_panels[new_tab_name]:
                     ui.label(f'Tool Area - Tab {self.area2_tab_counter}').classes('text-2xl font-bold mb-4')
@@ -443,7 +454,7 @@ class BibleMateGUI:
     def create_menu(self):
         """Create the responsive header and navigation drawer."""
         # --- Header ---
-        with ui.header(elevated=True).classes('bg-primary text-white'):
+        with ui.header(elevated=True).classes('bg-primary text-white p-0'):
             # We use 'justify-between' to push the left and right groups apart
             with ui.row().classes('w-full items-center justify-between no-wrap'):
                 
@@ -483,41 +494,43 @@ class BibleMateGUI:
                     
                     #with ui.row().classes('gt-xs items-center overflow-x-auto overflow-y-hidden no-wrap'):                            
                     # Bibles
-                    with ui.button(icon='book').props('flat color=white round').tooltip('Bibles'):
+                    with ui.button(icon='local_library').props('flat color=white round').tooltip('Bibles'):
                         with ui.menu():
                             ui.menu_item('Add Bible Tab', on_click=self.add_tab_area1)
                             ui.menu_item('Remove Bible Tab', on_click=self.remove_tab_area1)
                             ui.separator()
-                            ui.menu_item('Original Reader’s Bible', on_click=lambda: self.load_area_1_content(title='ORB'))
-                            ui.menu_item('Original Interlinear Bible', on_click=lambda: self.load_area_1_content(title='OIB'))
-                            ui.menu_item('Original Parallel Bible', on_click=lambda: self.load_area_1_content(title='OPB'))
-                            ui.menu_item('Original Discourse Bible', on_click=lambda: self.load_area_1_content(title='ODB'))
-                            ui.menu_item('Original Linguistic Bible', on_click=lambda: self.load_area_1_content(title='OLB'))
+                            ui.menu_item('Original Reader’s Bible', on_click=lambda: self.load_area_1_content(title='ORB')).tooltip('ORB')
+                            ui.menu_item('Original Interlinear Bible', on_click=lambda: self.load_area_1_content(title='OIB')).tooltip('OIB')
+                            ui.menu_item('Original Parallel Bible', on_click=lambda: self.load_area_1_content(title='OPB')).tooltip('OPB')
+                            ui.menu_item('Original Discourse Bible', on_click=lambda: self.load_area_1_content(title='ODB')).tooltip('ODB')
+                            ui.menu_item('Original Linguistic Bible', on_click=lambda: self.load_area_1_content(title='OLB')).tooltip('OLB')
                             ui.separator()
                             if app.storage.client["custom"] and config.bibles_custom:
                                 for i in config.bibles_custom:
-                                    ui.menu_item(i, on_click=partial(self.load_area_1_content, config.bible_translation, i))
+                                    ui.menu_item(i, on_click=partial(self.load_area_1_content, title=i)).tooltip(config.bibles_custom[i][0])
                                 ui.separator()
                             for i in config.bibles:
-                                ui.menu_item(i, on_click=partial(self.load_area_1_content, config.bible_translation, i))
+                                if (app.storage.client["custom"] and not i in config.bibles_custom) or not app.storage.client["custom"]:
+                                    ui.menu_item(i, on_click=partial(self.load_area_1_content, title=i)).tooltip(config.bibles[i][0])
 
-                    with ui.button(icon='menu_book').props('flat color=white round').tooltip('Parallel Bibles'):
+                    with ui.button(icon='devices_fold').props('flat color=white round').tooltip('Parallel Bibles'):
                         with ui.menu():
                             ui.menu_item('Add Parallel Tab', on_click=self.add_tab_area2)
                             ui.menu_item('Remove Parallel Tab', on_click=self.remove_tab_area2)
                             ui.separator()
-                            ui.menu_item('Original Reader’s Bible', on_click=lambda: self.load_area_2_content(title='ORB'))
-                            ui.menu_item('Original Interlinear Bible', on_click=lambda: self.load_area_2_content(title='OIB'))
-                            ui.menu_item('Original Parallel Bible', on_click=lambda: self.load_area_2_content(title='OPB'))
-                            ui.menu_item('Original Discourse Bible', on_click=lambda: self.load_area_2_content(title='ODB'))
-                            ui.menu_item('Original Linguistic Bible', on_click=lambda: self.load_area_2_content(title='OLB'))
+                            ui.menu_item('Original Reader’s Bible', on_click=lambda: self.load_area_2_content(title='ORB')).tooltip('ORB')
+                            ui.menu_item('Original Interlinear Bible', on_click=lambda: self.load_area_2_content(title='OIB')).tooltip('OIB')
+                            ui.menu_item('Original Parallel Bible', on_click=lambda: self.load_area_2_content(title='OPB')).tooltip('OPB')
+                            ui.menu_item('Original Discourse Bible', on_click=lambda: self.load_area_2_content(title='ODB')).tooltip('ODB')
+                            ui.menu_item('Original Linguistic Bible', on_click=lambda: self.load_area_2_content(title='OLB')).tooltip('OLB')
                             ui.separator()
                             if app.storage.client["custom"] and config.bibles_custom:
                                 for i in config.bibles_custom:
-                                    ui.menu_item(i, on_click=partial(self.load_area_2_content, config.bible_translation, i))
+                                    ui.menu_item(i, on_click=partial(self.load_area_2_content, title=i)).tooltip(config.bibles_custom[i][0])
                                 ui.separator()
                             for i in config.bibles:
-                                ui.menu_item(i, on_click=partial(self.load_area_2_content, config.bible_translation, i))
+                                if (app.storage.client["custom"] and not i in config.bibles_custom) or not app.storage.client["custom"]:
+                                    ui.menu_item(i, on_click=partial(self.load_area_2_content, title=i)).tooltip(config.bibles[i][0])
                             
 
                     # Bible Tools
@@ -527,7 +540,7 @@ class BibleMateGUI:
                             ui.menu_item('Remove Tool Tab', on_click=self.remove_tab_area2)
                             ui.separator()
                             ui.menu_item('Bible Verse', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Bible Audio', on_click=lambda: self.load_area_2_content(bibles_audio, 'Audio'))
+                            ui.menu_item('Bible Audio', on_click=lambda: self.load_area_2_content(title='Audio'))
                             ui.menu_item('Compare Chapter', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('Compare Verse', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.separator()
@@ -538,7 +551,7 @@ class BibleMateGUI:
                             ui.menu_item('Morphological Data', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('Translation Spectrum', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('Bible Timelines', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Bible Chronology', on_click=lambda: self.load_area_2_content(bible_chronology, 'Chronology'))
+                            ui.menu_item('Bible Chronology', on_click=lambda: self.load_area_2_content(title='Chronology'))
                     
                     """with ui.button(icon='book').props('flat color=white round'):
                         with ui.menu():
@@ -557,7 +570,7 @@ class BibleMateGUI:
                             ui.menu_item('Encyclopedia', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('Lexicon', on_click=lambda: self.load_area_2_content(self.work_in_progress))
 
-                    with ui.button(icon='bolt').props('flat color=white round').tooltip('AI'):
+                    with ui.button(icon='auto_awesome').props('flat color=white round').tooltip('AI'):
                         with ui.menu():
                             ui.menu_item('AI Commentary', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('AI Q&A', on_click=lambda: self.load_area_2_content(self.work_in_progress))
@@ -571,6 +584,19 @@ class BibleMateGUI:
                             ui.menu_item('Tool Only', on_click=lambda: self.swap_layout(3))
                             ui.menu_item('Bible & Tool', on_click=lambda: self.swap_layout(2))
                             ui.separator()
+                            with ui.menu_item() as dark_mode_menu_item:
+                                dark_mode_label = ui.label("Light Mode" if app.storage.user["dark_mode"] else "Dark Mode").classes('flex items-center')
+                            def toggle_dark_mode_menu_item(text_label: ui.label):
+                                app.storage.user['dark_mode'] = not app.storage.user['dark_mode']
+                                #text_label.set_text("Light Mode" if app.storage.user["dark_mode"] else "Dark Mode")
+                                ui.run_javascript('location.reload()')
+                            dark_mode_menu_item.on('click', lambda: toggle_dark_mode_menu_item(dark_mode_label))
+                            def toggleFullscreen(): # ui.fullscreen().toggle does not work in this case
+                                app.storage.user["fullscreen"] = not app.storage.user["fullscreen"]
+                            with ui.row():
+                                ui.menu_item('Fullscreen', on_click=toggleFullscreen)
+                                ui.switch().bind_value(app.storage.user, 'fullscreen')
+                            ui.separator()
                             ui.menu_item('Preferences', on_click=lambda: ui.navigate.to('/settings'))
 
         # --- Drawer (Mobile Menu) ---
@@ -587,87 +613,91 @@ class BibleMateGUI:
                 self.load_area_2_content(self.work_in_progress),
                 app.storage.user.update(left_drawer_open=False)
             )).props('clickable')
+            ui.switch('Dark Mode').bind_value(app.storage.user, 'dark_mode').on_value_change(lambda: ui.run_javascript('location.reload()'))
+            ui.switch('Fullscreen').bind_value(app.storage.user, 'fullscreen')
 
             # Bibles
-            with ui.expansion('Original', icon='book').props('header-class="text-primary"'):
+            with ui.expansion('Bibles', icon='local_library').props('header-class="text-secondary"'):
                 ui.item('Original Reader’s Bible', on_click=lambda: (
                     self.load_area_1_content(title='ORB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('ORB')
                 ui.item('Original Interlinear Bible', on_click=lambda: (
                     self.load_area_1_content(title='OIB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('OIB')
                 ui.item('Original Parallel Bible', on_click=lambda: (
                     self.load_area_1_content(title='OPB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('OPB')
                 ui.item('Original Discourse Bible', on_click=lambda: (
                     self.load_area_1_content(title='ODB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('ODB')
                 ui.item('Original Linguistic Bible', on_click=lambda: (
                     self.load_area_1_content(title='OLB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('OLB')
                 ui.separator()
                 if app.storage.client["custom"] and config.bibles_custom:
                     for i in config.bibles_custom:
                         ui.item(i, on_click=lambda: (
                             self.load_area_1_content(title=i),
                             app.storage.user.update(left_drawer_open=False)
-                        )).props('clickable')
+                        )).props('clickable').tooltip(config.bibles_custom[i][0])
                     ui.separator()
                 for i in config.bibles:
-                    ui.item(i, on_click=lambda: (
-                        self.load_area_1_content(title=i),
-                        app.storage.user.update(left_drawer_open=False)
-                    )).props('clickable')
+                    if (app.storage.client["custom"] and not i in config.bibles_custom) or not app.storage.client["custom"]:
+                        ui.item(i, on_click=lambda: (
+                            self.load_area_1_content(title=i),
+                            app.storage.user.update(left_drawer_open=False)
+                        )).props('clickable').tooltip(config.bibles[i][0])
 
             # Parallel Bibles
-            with ui.expansion('Original', icon='book').props('header-class="text-primary"'):
+            with ui.expansion('Parallel Bibles', icon='devices_fold').props('header-class="text-secondary"'):
                 ui.item('Original Reader’s Bible', on_click=lambda: (
                     self.load_area_2_content(title='ORB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('ORB')
                 ui.item('Original Interlinear Bible', on_click=lambda: (
                     self.load_area_2_content(title='OIB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('OIB')
                 ui.item('Original Parallel Bible', on_click=lambda: (
                     self.load_area_2_content(title='OPB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('OPB')
                 ui.item('Original Discourse Bible', on_click=lambda: (
                     self.load_area_2_content(title='ODB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('ODB')
                 ui.item('Original Linguistic Bible', on_click=lambda: (
                     self.load_area_2_content(title='OLB'),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')
+                )).props('clickable').tooltip('OLB')
                 ui.separator()
                 if app.storage.client["custom"] and config.bibles_custom:
                     for i in config.bibles_custom:
                         ui.item(i, on_click=lambda: (
                             self.load_area_2_content(title=i),
                             app.storage.user.update(left_drawer_open=False)
-                        )).props('clickable')
+                        )).props('clickable').tooltip(config.bibles_custom[i][0])
                     ui.separator()
                 for i in config.bibles:
-                    ui.item(i, on_click=lambda: (
-                        self.load_area_2_content(title=i),
-                        app.storage.user.update(left_drawer_open=False)
-                    )).props('clickable')
+                    if (app.storage.client["custom"] and not i in config.bibles_custom) or not app.storage.client["custom"]:
+                        ui.item(i, on_click=lambda: (
+                            self.load_area_2_content(title=i),
+                            app.storage.user.update(left_drawer_open=False)
+                        )).props('clickable').tooltip(config.bibles[i][0])
 
             # Bible Tools
-            with ui.expansion('Tools', icon='build').props('header-class="text-primary"'):
+            with ui.expansion('Tools', icon='build').props('header-class="text-secondary"'):
                 ui.item('Bible Verse', on_click=lambda: (
                     self.load_area_2_content(self.work_in_progress),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Bible Audio', on_click=lambda: (
-                    self.load_area_2_content(bibles_audio, 'Audio'),
+                    self.load_area_2_content(title='Audio'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Compare Chapter', on_click=lambda: (
@@ -708,12 +738,12 @@ class BibleMateGUI:
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Bible Chronology', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                    self.load_area_2_content(title='Chronology'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
 
             # Search
-            with ui.expansion('Search', icon='search').props('header-class="text-primary"'):
+            with ui.expansion('Search', icon='search').props('header-class="text-secondary"'):
                 ui.item('Bibles', on_click=lambda: (
                     self.load_area_2_content(self.work_in_progress),
                     app.storage.user.update(left_drawer_open=False)
@@ -756,7 +786,7 @@ class BibleMateGUI:
                 )).props('clickable')
             
             # AI
-            with ui.expansion('AI', icon='bolt').props('header-class="text-primary"'):
+            with ui.expansion('AI', icon='auto_awesome').props('header-class="text-secondary"'):
                 ui.item('AI Commentary', on_click=lambda: (
                     self.load_area_2_content(self.work_in_progress),
                     app.storage.user.update(left_drawer_open=False)
@@ -778,13 +808,23 @@ class BibleMateGUI:
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
 
-            # About Expansion
-            '''with ui.expansion('About Us', icon='info'):
-                ui.item('Our Church', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+            # Preferences
+            with ui.expansion('Settings', icon='auto_awesome').props('header-class="text-secondary"'):
+                ui.item('Bible Only', on_click=lambda: (
+                    self.swap_layout(1),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
-                ui.item('Contact', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                ui.item('Tool Only', on_click=lambda: (
+                    self.swap_layout(2),
                     app.storage.user.update(left_drawer_open=False)
-                )).props('clickable')'''
\ No newline at end of file
+                )).props('clickable')
+                ui.item('Bible & Tool', on_click=lambda: (
+                    self.swap_layout(3),
+                    app.storage.user.update(left_drawer_open=False)
+                )).props('clickable')
+                ui.separator()
+                ui.item('Preferences', on_click=lambda: (
+                    ui.navigate.to('/settings'),
+                    app.storage.user.update(left_drawer_open=False)
+                )).props('clickable')
+                ui.separator()
\ No newline at end of file
